@@ -17,5 +17,5 @@ limitations under the License.
 from .meta_viewer import MetaViewer
 from .metric_viewer import MetricViewer
 from .validator import DataValidationException, Validator, AggregateValidator, PredicateValidator
-from .meta_validator import MetaValidator
+from .meta_validator import Validator, MetaValidator
 from .history_viewer import HistoryViewer
